Attention is currently required from: Anastasia Klimchuk, Peter Marheine, Richard Hughes, Sergii Dmytruk.
Hello Peter Marheine, Richard Hughes, Sergii Dmytruk, build bot (Jenkins),
I'd like you to reexamine a change. Please visit
https://review.coreboot.org/c/flashrom/+/86031?usp=email
to look at the new patch set (#8).
The following approvals got outdated and were removed:
Code-Review+2 by Sergii Dmytruk, Verified+1 by build bot (Jenkins)
Change subject: libflashrom: Update the API for progress callback
......................................................................
libflashrom: Update the API for progress callback
The initial version of API for progress callback would require the
callback function to make a second call to get the needed data about
progress state (current, total etc).
This patch changes the callback API, so that callback function gets
all needed data straight away as parameters, and with this,
callback has all the data to do its job.
Since the initial version was submitted and it was in the tree for a
while, the change needs to add a _v2 suffix for new thing and
deprecated attribute for old thing.
Testing: both unit tests and cli are libflashrom clients.
All unit tests run successfully, for the cli all scenarios from
commit 75dc0655b95dde91f1426a7e5aecfc04d7b8d631 run successfully.
Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M cli_classic.c
M cli_output.c
M doc/release_notes/devel.rst
M flashrom.c
M include/cli_output.h
M include/flash.h
M include/libflashrom.h
M libflashrom.c
M libflashrom.map
M tests/chip.c
M tests/spi25.c
11 files changed, 119 insertions(+), 72 deletions(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/31/86031/8
--
To view, visit https://review.coreboot.org/c/flashrom/+/86031?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Gerrit-Change-Number: 86031
Gerrit-PatchSet: 8
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Richard Hughes <richard(a)hughsie.com>
Gerrit-Reviewer: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Richard Hughes <richard(a)hughsie.com>
Gerrit-Attention: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Attention: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>
Attention is currently required from: Anastasia Klimchuk, Peter Marheine, Richard Hughes.
Sergii Dmytruk has posted comments on this change by Anastasia Klimchuk. ( https://review.coreboot.org/c/flashrom/+/86031?usp=email )
Change subject: libflashrom: Update the API for progress callback
......................................................................
Patch Set 7: Code-Review+2
(3 comments)
File include/libflashrom.h:
https://review.coreboot.org/c/flashrom/+/86031/comment/8fcb378d_0cb23789?us… :
PS7, Line 112: */
The comment should probably have a note saying that this has priority over `flashrom_set_progress_callback()` when both are set. Not that it's very useful, but makes behaviour of the API less ambiguous.
File libflashrom.c:
https://review.coreboot.org/c/flashrom/+/86031/comment/ab9b1128_0a47fce7?us… :
PS7, Line 76: " ignoring this call since %s is deprecated\n",
nit: there is already a space on the previous line
https://review.coreboot.org/c/flashrom/+/86031/comment/25cc92c2_4a797814?us… :
PS7, Line 134: sizeof(flashctx->progress_state.user_data));
nit: Why use `memcpy()`? Types match, so simple assignments should do and will break if types change, while `memcpy()` might not notice it.
--
To view, visit https://review.coreboot.org/c/flashrom/+/86031?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Gerrit-Change-Number: 86031
Gerrit-PatchSet: 7
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Richard Hughes <richard(a)hughsie.com>
Gerrit-Reviewer: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Richard Hughes <richard(a)hughsie.com>
Gerrit-Attention: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Comment-Date: Sat, 15 Feb 2025 17:37:10 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Attention is currently required from: Dolan Liu, Nikolai Artemiev, Stefan Reinauer.
Anastasia Klimchuk has posted comments on this change by Dolan Liu. ( https://review.coreboot.org/c/flashrom/+/86348?usp=email )
Change subject: flashchips: Add Macronix MX77U25650FZ4I42
......................................................................
Patch Set 2:
(1 comment)
Patchset:
PS2:
> Hello Dolan, thank you for the patch. […]
Also, I know sometimes datasheets are not public but can be available only for partners for example. Let me know if this is the case, we can think what to do.
In general, every patch needs to be reviewed by someone who is not the author, and in this case the reviewer need to have access to the datasheet.
--
To view, visit https://review.coreboot.org/c/flashrom/+/86348?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: I7866b2db343f4eb2bc194400ceca099d3af3b87d
Gerrit-Change-Number: 86348
Gerrit-PatchSet: 2
Gerrit-Owner: Dolan Liu <liuyong5(a)huaqin.corp-partner.google.com>
Gerrit-Reviewer: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Nikolai Artemiev <nartemiev(a)google.com>
Gerrit-Reviewer: Stefan Reinauer <stefan.reinauer(a)coreboot.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Dolan Liu <liuyong5(a)huaqin.corp-partner.google.com>
Gerrit-Attention: Stefan Reinauer <stefan.reinauer(a)coreboot.org>
Gerrit-Attention: Nikolai Artemiev <nartemiev(a)google.com>
Gerrit-Comment-Date: Sat, 15 Feb 2025 09:27:07 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: Anastasia Klimchuk <aklm(a)chromium.org>
Anastasia Klimchuk has uploaded this change for review. ( https://review.coreboot.org/c/flashrom/+/86432?usp=email )
Change subject: [WIP EXPERIMENT] Give priority to SFDP is chip supports it
......................................................................
[WIP EXPERIMENT] Give priority to SFDP is chip supports it
The patch changes the idea how the chips are probed.
Previously, probing would go through the whole list of flashchips
and try each of them, and only if none of the entries match
then SFDP is attempted as a fallback.
This patch aims to probe with SFDP first, and if the chip responds,
probing stops there and all further work with the chip is done via
SFDP.
If the chip does not support SFDP, we fallback to going through the
list of flashchips and probing each.
Note this patch does not affect the behaviour when command line
option `-c <chip_name>` is used. Providing chip name explicitly will
only probe for one entry in flashchips, with the given name.
NOTE for this to land, we need to do one more feature:
parsing reg_bits info for write-protection from SFDP header (similar
to what rpmc implementation is doing). Without parsing reg_bits
from SFDP header, wp operations won't work with this patch, unless
using direct option `-c <chip_name>`.
Change-Id: I8bd96742b7365be16dc277d42b14c5a44ef7f7a9
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M cli_classic.c
M flashchips.c
M flashrom.c
M libflashrom.c
M tests/dummyflasher.c
M tests/tests.c
M tests/tests.h
7 files changed, 52 insertions(+), 27 deletions(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/32/86432/1
diff --git a/cli_classic.c b/cli_classic.c
index 1a0565b..401dc9f 100644
--- a/cli_classic.c
+++ b/cli_classic.c
@@ -1210,7 +1210,7 @@
startchip = 0;
while (chipcount < (int)ARRAY_SIZE(flashes)) {
startchip = probe_flash(®istered_masters[j], startchip, &flashes[chipcount], 0, options.chip_to_probe);
- if (startchip == -1)
+ if (startchip == -1 || (flashes[chipcount].chip->model_id == SFDP_DEVICE_ID))
break;
chipcount++;
startchip++;
diff --git a/flashchips.c b/flashchips.c
index 615419d..0bd04ef 100644
--- a/flashchips.c
+++ b/flashchips.c
@@ -55,6 +55,31 @@
* .voltage = Voltage range in millivolt
*/
+ /*
+ * SFDP chip entry is intentionally placed first in the list.
+ */
+ {
+ .vendor = "Any",
+ .name = "SFDP-capable chip",
+ .bustype = BUS_SPI,
+ .manufacture_id = GENERIC_MANUF_ID,
+ .model_id = SFDP_DEVICE_ID,
+ .total_size = 0, /* set by probing function */
+ .page_size = 0, /* set by probing function */
+ .feature_bits = 0, /* set by probing function */
+ /* We present our own "report this" text hence we do not */
+ /* want the default "This flash part has status UNTESTED..." */
+ /* text to be printed. */
+ .tested = { .probe = OK, .read = OK, .erase = OK, .write = OK, .wp = NA },
+ .probe = PROBE_SPI_SFDP,
+ .block_erasers = {}, /* set by probing function */
+ .unlock = SPI_DISABLE_BLOCKPROTECT, /* is this safe? */
+ .write = 0, /* set by probing function */
+ .read = SPI_CHIP_READ,
+ /* FIXME: some vendor extensions define this */
+ .voltage = {0},
+ },
+
/* TODO: Refactor implementation to avoid these .c includes */
#include "flashchips/amd.c"
#include "flashchips/amic.c"
@@ -95,28 +120,6 @@
* These entries are intentionally placed at the end.
*/
{
- .vendor = "Unknown",
- .name = "SFDP-capable chip",
- .bustype = BUS_SPI,
- .manufacture_id = GENERIC_MANUF_ID,
- .model_id = SFDP_DEVICE_ID,
- .total_size = 0, /* set by probing function */
- .page_size = 0, /* set by probing function */
- .feature_bits = 0, /* set by probing function */
- /* We present our own "report this" text hence we do not */
- /* want the default "This flash part has status UNTESTED..." */
- /* text to be printed. */
- .tested = { .probe = OK, .read = OK, .erase = OK, .write = OK, .wp = NA },
- .probe = PROBE_SPI_SFDP,
- .block_erasers = {}, /* set by probing function */
- .unlock = SPI_DISABLE_BLOCKPROTECT, /* is this safe? */
- .write = 0, /* set by probing function */
- .read = SPI_CHIP_READ,
- /* FIXME: some vendor extensions define this */
- .voltage = {0},
- },
-
- {
.vendor = "Programmer",
.name = "Opaque flash chip",
.bustype = BUS_PROG,
diff --git a/flashrom.c b/flashrom.c
index 8daad74..228db69 100644
--- a/flashrom.c
+++ b/flashrom.c
@@ -1153,7 +1153,10 @@
/* If this is the first chip found, accept it.
* If this is not the first chip found, accept it only if it is
- * a non-generic match. SFDP and CFI are generic matches.
+ * a non-generic match. CFI is a generic match.
+ *
+ * SFDP is a special match which takes priority when it's found.
+ *
* startchip==0 means this call to probe_flash() is the first
* one for this programmer interface (master) and thus no other chip has
* been found on this interface.
@@ -1178,7 +1181,7 @@
if (startchip == 0)
break;
/* Not the first flash chip detected on this bus, but not a generic match either. */
- if ((flash->chip->model_id != GENERIC_DEVICE_ID) && (flash->chip->model_id != SFDP_DEVICE_ID))
+ if (flash->chip->model_id != GENERIC_DEVICE_ID)
break;
/* Not the first flash chip detected on this bus, and it's just a generic match. Ignore it. */
notfound:
diff --git a/tests/dummyflasher.c b/tests/dummyflasher.c
index 9878bef..80cfe38 100644
--- a/tests/dummyflasher.c
+++ b/tests/dummyflasher.c
@@ -55,6 +55,19 @@
run_probe_lifecycle(state, &dummy_io, &programmer_dummy, "size=8388608,emulate=VARIABLE_SIZE", "Opaque flash chip");
}
+void dummy_probe_sdfp_chip(void **state)
+{
+ struct io_mock_fallback_open_state dummy_fallback_open_state = {
+ .noc = 0,
+ .paths = { NULL },
+ };
+ const struct io_mock dummy_io = {
+ .fallback_open_state = &dummy_fallback_open_state,
+ };
+
+ run_probe_lifecycle(state, &dummy_io, &programmer_dummy, "bus=spi,emulate=MX25L6436", NULL);
+}
+
void dummy_init_fails_unhandled_param_test_success(void **state)
{
struct io_mock_fallback_open_state dummy_fallback_open_state = {
@@ -164,6 +177,7 @@
SKIP_TEST(dummy_basic_lifecycle_test_success)
SKIP_TEST(dummy_probe_lifecycle_test_success)
SKIP_TEST(dummy_probe_variable_size_test_success)
+ SKIP_TEST(dummy_probe_sdfp_chip)
SKIP_TEST(dummy_init_fails_unhandled_param_test_success)
SKIP_TEST(dummy_init_success_invalid_param_test_success)
SKIP_TEST(dummy_init_success_unhandled_param_test_success)
diff --git a/tests/tests.c b/tests/tests.c
index 72b4868..6d863ee 100644
--- a/tests/tests.c
+++ b/tests/tests.c
@@ -457,6 +457,7 @@
cmocka_unit_test(dummy_basic_lifecycle_test_success),
cmocka_unit_test(dummy_probe_lifecycle_test_success),
cmocka_unit_test(dummy_probe_variable_size_test_success),
+ cmocka_unit_test(dummy_probe_sdfp_chip),
cmocka_unit_test(dummy_init_fails_unhandled_param_test_success),
cmocka_unit_test(dummy_init_success_invalid_param_test_success),
cmocka_unit_test(dummy_init_success_unhandled_param_test_success),
diff --git a/tests/tests.h b/tests/tests.h
index 85c4f52..ccd52ed 100644
--- a/tests/tests.h
+++ b/tests/tests.h
@@ -48,6 +48,7 @@
void dummy_basic_lifecycle_test_success(void **state);
void dummy_probe_lifecycle_test_success(void **state);
void dummy_probe_variable_size_test_success(void **state);
+void dummy_probe_sdfp_chip(void **state);
void dummy_init_fails_unhandled_param_test_success(void **state);
void dummy_init_success_invalid_param_test_success(void **state);
void dummy_init_success_unhandled_param_test_success(void **state);
--
To view, visit https://review.coreboot.org/c/flashrom/+/86432?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: I8bd96742b7365be16dc277d42b14c5a44ef7f7a9
Gerrit-Change-Number: 86432
Gerrit-PatchSet: 1
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Anastasia Klimchuk has uploaded this change for review. ( https://review.coreboot.org/c/flashrom/+/86430?usp=email )
Change subject: doc: Add useful links to README
......................................................................
doc: Add useful links to README
Change-Id: Ib231150acd8aa911d534f67ff1ce937c6963812c
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M README.rst
1 file changed, 6 insertions(+), 1 deletion(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/30/86430/1
diff --git a/README.rst b/README.rst
index 2900517..a0ed3e8 100644
--- a/README.rst
+++ b/README.rst
@@ -19,6 +19,9 @@
Please see the flashrom(8) manpage :doc:`classic_cli_manpage`.
+The list of platforms that package flashrom can be found on `repology.org <https://repology.org/project/flashrom/versions>`_.
+
+Information about recent releases can be found in :doc:`/release_notes/index`.
Building / installing / packaging
---------------------------------
@@ -33,7 +36,9 @@
meson install -C builddir
For full detailed instructions, follow the information in
-:doc:`dev_guide/building_from_source`
+:doc:`dev_guide/building_from_source`.
+
+If you are interested in development, have a look at :doc:`dev_guide/development_guide`.
Contact
-------
--
To view, visit https://review.coreboot.org/c/flashrom/+/86430?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ib231150acd8aa911d534f67ff1ce937c6963812c
Gerrit-Change-Number: 86430
Gerrit-PatchSet: 1
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Anastasia Klimchuk has uploaded this change for review. ( https://review.coreboot.org/c/flashrom/+/86429?usp=email )
Change subject: doc: Add missing step in the beginning of building from source doc
......................................................................
doc: Add missing step in the beginning of building from source doc
Change-Id: Id834d3de69c038f3cc1aee3c59c3607f42fd5b49
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M doc/dev_guide/building_from_source.rst
M doc/dev_guide/development_guide.rst
2 files changed, 5 insertions(+), 0 deletions(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/29/86429/1
diff --git a/doc/dev_guide/building_from_source.rst b/doc/dev_guide/building_from_source.rst
index 73f5c2b..a8521ce 100644
--- a/doc/dev_guide/building_from_source.rst
+++ b/doc/dev_guide/building_from_source.rst
@@ -1,6 +1,9 @@
Building from source
====================
+First thing, clone git repository for yourself (if you haven't done it already),
+see :ref:`git repo setup`.
+
You're going to need the following tools to get started:
* gcc or clang
diff --git a/doc/dev_guide/development_guide.rst b/doc/dev_guide/development_guide.rst
index aac3a6c..621ee25 100644
--- a/doc/dev_guide/development_guide.rst
+++ b/doc/dev_guide/development_guide.rst
@@ -15,6 +15,8 @@
You can `look at the latest flashrom development efforts in Gerrit <https://review.coreboot.org/q/project:flashrom>`_.
+.. _git repo setup:
+
Set up the git repository and dev environment
=============================================
diff --git a/libflashrom.c b/libflashrom.c
index 78e5c9b..db8625b 100644
--- a/libflashrom.c
+++ b/libflashrom.c
@@ -21,6 +21,7 @@
#include <stdarg.h>
#include "flash.h"
+#include "flashchips.h"
#include "fmap.h"
#include "programmer.h"
#include "layout.h"
@@ -249,8 +250,10 @@
int flash_idx = -1;
if (!ret || (flash_idx = probe_flash(®istered_masters[i], 0, *flashctx, 0, chip_name)) != -1) {
ret = 0;
- /* We found one chip, now check that there is no second match. */
- if (probe_flash(®istered_masters[i], flash_idx + 1, &second_flashctx, 0, chip_name) != -1) {
+ /* We found one chip, if this is SFDP-capable chip then we don't need to look further.
+ * Otherwise we check that there is no second match. */
+ if (((*flashctx)->chip->model_id != SFDP_DEVICE_ID)
+ && probe_flash(®istered_masters[i], flash_idx + 1, &second_flashctx, 0, chip_name) != -1) {
flashrom_layout_release(second_flashctx.default_layout);
free(second_flashctx.chip);
ret = 3;
--
To view, visit https://review.coreboot.org/c/flashrom/+/86429?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Id834d3de69c038f3cc1aee3c59c3607f42fd5b49
Gerrit-Change-Number: 86429
Gerrit-PatchSet: 1
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Attention is currently required from: Peter Marheine.
Anastasia Klimchuk has posted comments on this change by Peter Marheine. ( https://review.coreboot.org/c/flashrom/+/86350?usp=email )
Change subject: doc: autogenerate a list of authors
......................................................................
Patch Set 5:
(2 comments)
Patchset:
PS5:
Adding a comment so that not to forget: the hard-coded list of authors on the bottom of the manpage is not needed anymore, we can add a link to this page instead (something like, The full list of authors and reviewers is here: <link>)
File doc/about_flashrom/hall_of_fame.rst:
https://review.coreboot.org/c/flashrom/+/86350/comment/9f244422_13e28fa3?us… :
PS5, Line 1: This page lists all past contributors to Flashrom. Specifically, it lists
: everybody who is named in the git history as having authored, co-authored,
: or reviewed at least one change in alphabetical order.
Two comments here, not to forget
1) title of the document is missing (Hall of Fame)
2) The three intro texts I composed, one intro for everything and a little intros for every section :)
--
To view, visit https://review.coreboot.org/c/flashrom/+/86350?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: I1e9634a90e84262aafd80590deba9875f4b71a3c
Gerrit-Change-Number: 86350
Gerrit-PatchSet: 5
Gerrit-Owner: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Comment-Date: Sat, 15 Feb 2025 07:35:15 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Attention is currently required from: Peter Marheine, Richard Hughes, Sergii Dmytruk.
Anastasia Klimchuk has posted comments on this change by Anastasia Klimchuk. ( https://review.coreboot.org/c/flashrom/+/86031?usp=email )
Change subject: libflashrom: Update the API for progress callback
......................................................................
Patch Set 7:
(2 comments)
File include/libflashrom.h:
https://review.coreboot.org/c/flashrom/+/86031/comment/96ae1b25_b8a2b30c?us… :
PS2, Line 90: * @deprecated Use flashrom_set_progress_callback_v1 instead
> There could still be a pointer to a client-managed progress state along with the internal state, just need to copy data into the former before invoking v1 callback.
It is also clever and it works! I made the last patchset with this solution. Thank you!
And then, I will keep in mind that it will be possible to remove the deprecated code in v2.0
Thank you for link to repology.org, it was very interesting for me to look at flashrom package :) For libflashrom, I understand there are not many users but anyway I am happy that we have solution that doesn't break anyone.
File libflashrom.c:
https://review.coreboot.org/c/flashrom/+/86031/comment/e2ea7380_78f0cae2?us… :
PS5, Line 70: flashctx->progress_state = progress_state;
> This line is no longer possible , with the change in line 625 in include/flash. […]
Done
--
To view, visit https://review.coreboot.org/c/flashrom/+/86031?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Gerrit-Change-Number: 86031
Gerrit-PatchSet: 7
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Richard Hughes <richard(a)hughsie.com>
Gerrit-Reviewer: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Richard Hughes <richard(a)hughsie.com>
Gerrit-Attention: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Comment-Date: Fri, 14 Feb 2025 11:58:04 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: Anastasia Klimchuk <aklm(a)chromium.org>
Comment-In-Reply-To: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Attention is currently required from: Anastasia Klimchuk, Peter Marheine, Richard Hughes.
Hello Peter Marheine, Richard Hughes, Sergii Dmytruk, build bot (Jenkins),
I'd like you to reexamine a change. Please visit
https://review.coreboot.org/c/flashrom/+/86031?usp=email
to look at the new patch set (#7).
The following approvals got outdated and were removed:
Verified+1 by build bot (Jenkins)
Change subject: libflashrom: Update the API for progress callback
......................................................................
libflashrom: Update the API for progress callback
The initial version of API for progress callback would require the
callback function to make a second call to get the needed data about
progress state (current, total etc).
This patch changes the callback API, so that callback function gets
all needed data straight away as parameters, and with this,
callback has all the data to do its job.
Since the initial version was submitted and it was in the tree for a
while, the change needs to add a _v2 suffix for new thing and
deprecated attribute for old thing.
Testing: both unit tests and cli are libflashrom clients.
All unit tests run successfully, for the cli all scenarios from
commit 75dc0655b95dde91f1426a7e5aecfc04d7b8d631 run successfully.
Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M cli_classic.c
M cli_output.c
M doc/release_notes/devel.rst
M flashrom.c
M include/cli_output.h
M include/flash.h
M include/libflashrom.h
M libflashrom.c
M libflashrom.map
M tests/chip.c
M tests/spi25.c
11 files changed, 118 insertions(+), 72 deletions(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/31/86031/7
--
To view, visit https://review.coreboot.org/c/flashrom/+/86031?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Gerrit-Change-Number: 86031
Gerrit-PatchSet: 7
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Richard Hughes <richard(a)hughsie.com>
Gerrit-Reviewer: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Richard Hughes <richard(a)hughsie.com>
Gerrit-Attention: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>
Attention is currently required from: Anastasia Klimchuk, Peter Marheine, Richard Hughes.
Hello Peter Marheine, Richard Hughes, Sergii Dmytruk, build bot (Jenkins),
I'd like you to reexamine a change. Please visit
https://review.coreboot.org/c/flashrom/+/86031?usp=email
to look at the new patch set (#6).
The following approvals got outdated and were removed:
Verified+1 by build bot (Jenkins)
Change subject: libflashrom: Update the API for progress callback
......................................................................
libflashrom: Update the API for progress callback
The initial version of API for progress callback would require the
callback function to make a second call to get the needed data about
progress state (current, total etc).
This patch changes the callback API, so that callback function gets
all needed data straight away as parameters, and with this,
callback has all the data to do its job.
Since the initial version was submitted and it was in the tree for a
while, the change needs to add a _v2 suffix for new thing and
deprecated attribute for old thing.
Testing: both unit tests and cli are libflashrom clients.
All unit tests run successfully, for the cli all scenarios from
commit 75dc0655b95dde91f1426a7e5aecfc04d7b8d631 run successfully.
Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Signed-off-by: Anastasia Klimchuk <aklm(a)flashrom.org>
---
M cli_classic.c
M cli_output.c
M doc/release_notes/devel.rst
M flashrom.c
M include/cli_output.h
M include/flash.h
M include/libflashrom.h
M libflashrom.c
M libflashrom.map
M tests/chip.c
M tests/spi25.c
11 files changed, 117 insertions(+), 71 deletions(-)
git pull ssh://review.coreboot.org:29418/flashrom refs/changes/31/86031/6
--
To view, visit https://review.coreboot.org/c/flashrom/+/86031?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: flashrom
Gerrit-Branch: main
Gerrit-Change-Id: Ia8cc0461c449b7e65888a64cdc594c55b81eae7a
Gerrit-Change-Number: 86031
Gerrit-PatchSet: 6
Gerrit-Owner: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Reviewer: Peter Marheine <pmarheine(a)chromium.org>
Gerrit-Reviewer: Richard Hughes <richard(a)hughsie.com>
Gerrit-Reviewer: Sergii Dmytruk <sergii.dmytruk(a)3mdeb.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Richard Hughes <richard(a)hughsie.com>
Gerrit-Attention: Anastasia Klimchuk <aklm(a)chromium.org>
Gerrit-Attention: Peter Marheine <pmarheine(a)chromium.org>